import { Injectable } from '@angular/core';
import { HttpHandler, HttpInterceptor, HttpRequest } from '@angular/common/http';
import { Observable } from 'rxjs';
import { HttpEvent } from '@angular/common/http/src/response';

@Injectable()
export class ContentTypeInterceptor implements HttpInterceptor {

  intercept(req: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {

    if (req.headers.has('Content-Type')) {

      // browser will set the boundary automatically only if the content type
      // was not specified
      if (req.headers.get('Content-Type') === 'multipart/form-data') {
        const cloned = req.clone({
          headers: req.headers.delete('Content-Type')
        });
        return next.handle(cloned);
      }

      // normal behaviour
      return next.handle(req);

    }

    // assign default content type
    const cloned = req.clone({
      headers: req.headers.set('Content-Type', 'application/json')
    });
    return next.handle(cloned);

  }

}
