import { Injectable } from '@angular/core';
import { HttpErrorResponse, HttpHandler, HttpInterceptor, HttpRequest } from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { catchError } from 'rxjs/operators';
import { HttpEvent} from '@angular/common/http/src/response';

// issue https://github.com/dherges/ng-packagr/issues/696
// @dynamic
@Injectable()
export class ErrorInterceptor implements HttpInterceptor {

  intercept(req: HttpRequest<any>, next: HttpHandler) : Observable<HttpEvent<any>>{
    return next.handle(req)
      .pipe(catchError(this.handleError));
  }

  private handleError(response: HttpErrorResponse) {

    if (response.error instanceof Blob && response.error.type === 'application/json') {
      return ErrorInterceptor.processBlobError(response);
    }

    console.log(JSON.stringify(response));
    return throwError(ErrorInterceptor.parseErrorMessage(response));

  };

  /* TODO: validar que se haya corregido el issue https://github.com/angular/angular/issues/19888 - este código es un fix */
  private static processBlobError(response: HttpErrorResponse) {

    return new Promise<any>((resolve, reject) => {

      const reader: FileReader = new FileReader();
      reader.addEventListener("loadend", function() {
        try {
          const parsed = JSON.parse(reader.result);

          console.log(reader.result);
          reject(ErrorInterceptor.parseErrorMessage(parsed));

        } catch (e) {
          reject(e);
        }
      });

      reader.readAsText(response.error);

    });

  }

  // noinspection JSMethodCanBeStatic
  private static parseErrorMessage(response: any): string | any {

    if (response.error && response.error.error_description) {
      return response.error.error_description;
    }
    return response;

  }

}
