import { HttpHeaders } from '@angular/common/http';
import { AuthConfig } from './entities/auth.config';

export const AuthDefaults = {

  grantTypes: {
    login: 'password',
    token: 'refresh_token'
  },
  urls: {
    simpleToken: (config: AuthConfig) => `${config.authEndpoint}/oauth/token`,
    facebookToken:(config:AuthConfig, token:string) => `${config.authEndpoint}/facebook/token/${token}`
  },
  headers: (config: AuthConfig, deviceId: string) => {

    if (config.authorization && config.authorization.type && deviceId === undefined) {
      return new HttpHeaders({
        'Content-Type': 'application/x-www-form-urlencoded',
        'Authorization': `${config.authorization.type} ${config.authorization.credentials}`
      })
    } else if (config.authorization && config.authorization.type && deviceId !== undefined) {
      return new HttpHeaders({
          'Content-Type': 'application/x-www-form-urlencoded',
          'Authorization': config.authorization.type + " " + config.authorization.credentials,
          'X-BBVA-Deviceid': deviceId
      });
    }

    return new HttpHeaders({
      'Content-Type': 'application/x-www-form-urlencoded'
    });

  },
  defaultAuthConfig: {
    defaultTokenName: 'token',
    defaultHeaderName: 'Authorization',
    headerPrefixBearer: 'Bearer ',
  }
};
